"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _pluginOption = _interopRequireDefault(require("./utils/pluginOption"));

var _tools = require("./utils/tools");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _default({
  types: t
}) {
  const visitor = {
    CallExpression(path) {
      if (t.isMemberExpression(path.node.callee) && path.node.callee.object.name === 'console') {
        // options need to be an object
        if (this.opts && !(0, _tools.isObject)(this.opts)) {
          return console.error('[babel-plugin-console-enhanced]: options need to be an object.');
        }

        const options = (0, _pluginOption.default)(this.opts);
        const filename = this.filename || this.file.opts.filename || 'unknown'; // not work on excluded files, and exclude is proiority other than include

        if (Array.isArray(options.exclude) && options.exclude.length && (0, _tools.matchesFile)(options.exclude, filename)) {
          return;
        } // just work on included files


        if (Array.isArray(options.include) && options.include.length && !(0, _tools.matchesFile)(options.include, filename)) {
          return;
        } // not work on a non-inlcuded method


        if (!options.methods.includes(path.node.callee.property.name)) {
          return;
        }

        let description = '';

        if (options.needFilename) {
          description = `${description}filename: ${filename}, `;
        }

        if (options.needLineNo) {
          const line = path.node.loc ? path.node.loc.start ? path.node.loc.start.line : undefined : undefined;
          description = `${description}lineNo: ${line}, `;
        }

        if (options.needColumnNo) {
          const column = path.node.loc ? path.node.loc.start ? path.node.loc.start.column : undefined : undefined;
          description = `${description}columnNo: ${column}, `;
        }

        if (options.needContext) {
          const scope = (0, _tools.computeContext)(path);
          description = scope ? `${description}context: ${scope}, ` : description;
        }

        if (options.customContent) {
          description = `${description}${options.customContent}, `;
        }

        if (description) {
          path.node.arguments.unshift(t.stringLiteral(description));
        }
      }
    }

  };
  return {
    name: 'babel-plugin-console-enhanced',
    visitor
  };
}